`orthant.craig` <-
  function(mu, Sigma, istart=1, conesonly=F, log2G=8, zmax=8, S=.02) {
    n = length(mu)
    if(istart>1) {
      ind = c(istart, (1:n)[-istart])
      Sigma = Sigma[ind, ind]
      mu = mu[ind]
    }
    At = tryCatch(chol(Sigma), error = function(e) NULL)
    if(is.null(At)) return(NA)
    tmp = backsolve(At, cbind(mu, diag(n)), transpose = T)
    mutilde = tmp[, 1]
    V = tmp[, -1, drop = F]
    scales = sqrt(rep(1, n) %*% V^2)
    V = sweep(V, 2, scales, "/")
    At = sweep(At, 2, scales, "*")
    result =  PSCdecomp(
      V, At, 1, mutilde, 
      conesonly = conesonly, 
      log2G = log2G, zmax = zmax, S = S)
    if (result$value<0) result$value = 0
    result
  }

`PSCdecomp` <-
  function(V, At, p, mu, conesonly=F, log2G=8, zmax=8, S=.02) {
    n = nrow(V)
    
    Cprob=.C("PSC_decomp_R",
      as.integer(n),
      as.double(V), as.double(At), as.double(mu),
      as.integer(p),
      as.integer(log2G), as.double(zmax), as.double(S),
      as.integer(conesonly),
      cones=integer(1),
      val=double(1),
      PACKAGE="orthants")
    return(list(value=Cprob$val, cones=Cprob$cones))
  }
