\name{orthant.ar}
\alias{orthant.ar}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{AR(1) MVN Orthant Probability}
\description{
  Computes a unit variance (non-stationary) autogressive multivariate
  normal orthant probability using the method of Craig (2007?)
}
\usage{
orthant.ar(mu, rho, log2G = 8, zmax = 8, S = 0.02)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{mu}{The mean (vector) of the distribution}
  \item{rho}{Vector of correlations between successive elements of the
    random vector}
  \item{log2G}{The base 2 logarithm of the number of grid points used
    for numerical approximation}
  \item{zmax}{The magnitude beyond which the standard normal is
    has approximately no probability}
  \item{S}{The threshold determining the switch between using linear
    filtering and using the Fast
    Fourier Transform}
}
\details{
  Computes the orthant probability (probability that each component of the
  random vector is positive) for a multivariate normal
  distribution in the case of unit variances and a (non-stationary)
  first-order auto-regressive (Markov) sequence.
  Since the distribution is auto-regressive the correlation matrix is
  determined by the correlations between adjacent elements of the random
  vector.

  This function implements the algorithm published by Craig
  (2007?). 
  
  Increasing \code{log2G} should improve the accuracy of computation.

  Increasing \code{zmax} may increase accuracy in extreme cases.

  Changing \code{S} may lead to greater efficiency on some hardware
}
\value{
  The orthant probability.
}
\references{Craig P (2007) A new reconstruction of multivariate normal orthant probabilities.}
\author{Peter Craig}
\seealso{\code{\link{orthant.craig}}, \code{\link{orthant.miwa}}, the
  \code{mvtnorm} package}
\examples{
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{math}

