\name{orthant.craig}
\alias{orthant.craig}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{MVN Orthant Probability (Craig)}
\description{
  Computes a multivariate normal orthant probability using the method of
  Craig (2007?)
}
\usage{
orthant.craig(mu, Sigma, istart = 1, conesonly = F, log2G = 8, zmax = 8, S = 0.02)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{mu}{The mean (vector) of the distribution}
  \item{Sigma}{The variance (matrix) of the distribution}
  \item{istart}{A positive integer determing the starting component}
  \item{conesonly}{if \code{TRUE}, just compute the number of cones in
    the reconstruction without computing the probability}
  \item{log2G}{The base 2 logarithm of the number of grid points used
    for numerical approximation}
  \item{zmax}{The magnitude beyond which the standard normal is
    has approximately no probability}
  \item{S}{The threshold determining the switch between using linear
    filtering and using the Fast Fourier Transform}
}
\details{
  The orthant probability is the probability that each component of the
  random vector is positive.
  
  This function implements the algorithm published by Craig
  (2007?). The original probability is reconstructed in terms of
  probabilities for edge-orthoscheme cones. The number of cones required
  may depend on the choice of which component of the random vector is used
  to start the algorithm.  Computing the probability for each cone can
  take considerable effort so it may be worth finding out first which
  value of \code{istart} requires the least number of cones.
  
  Increasing \code{log2G} should improve the accuracy of computation.

  Increasing \code{zmax} may increase accuracy in extreme cases.

  Changing \code{S} may lead to greater efficiency on some hardware
}
\value{
  A list with two components
  \item{value}{The estimated orthant probability}
  \item{cones}{The number of cones required}
}
\references{Craig P (2007) A new reconstruction of multivariate normal orthant probabilities.}
\author{Peter Craig}
\seealso{\code{\link{orthant.miwa}}, \code{\link{orthant.ar}},
  the \code{mvtnorm} package}
\examples{
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ math }

