/*
 * Include file for calculating orthant probabilities
 *
 * Stored in
 *   "orthant.h"
 *
 * Last modified:
 *   2003-05-06
 *
 * (c) 2001-2003 T. Miwa
 *
 */


/* We can use system's erf() if availabel (and faster).
 * Define the following line.
 */
#ifdef FOR_R
#include <R.h>
#include <Rmath.h>
#include <R_ext/Utils.h>
#undef  USE_SYSTEM_ERF
#endif


#include <math.h>

#ifdef  __CYGWIN__
#define MAXM    16    /* maximum dimension size  */
#define MAXGRD  1025  /* maximum number of grid points */
#else
#define MAXM    20    /* maximum dimension size  */
#define MAXGRD  4097  /* maximum number of grid points */
#endif  /* __CYGWIN__ */


/* normal density function */
#define nrml_dn(X)  (exp(-0.5*(X)*(X)) * 0.39894228040143268)

/* normal cumulative distribution function
 */
#ifdef USE_SYSTEM_ERF /* sytem's erf() function */
/*   erf(x)  = (2/sqrt(pi)) integral{0 to x} of e(-t^2) dt
 *   = Pr{ |N(0, 1/sqrt(2))| < x }
 *   erfc(x) = 1.0 - erf(x)
 */
#define nrml_cd(X)  (((X) < 0.0) \
                      ? 0.5 - 0.5 * erf(-(X)*0.7071067811865475) \
                      : 0.5 + 0.5 * erf((X)*0.7071067811865475))
#elif defined FOR_R

# define nrml_cd(X) pnorm(X, 0, 1, 1, 0)

#else /* private nrml_lp() function */
/* If the system does not provide erf(),
 *   then you can use the nrml_lp()
 *   included in this package.
 */
#define TERM    20
#define BORDER  3.0
#define nrml_cd(X)  nrml_lp((X), TERM, BORDER)

extern double nrml_lp(double u, int term, double border);
#endif  /* nrml_cd(X) */


/* Grid information
 * The values are calculated in gridcalc.c
 *   and passed to "orschm.c" throuth "orthant.c".
 */
struct GRID{
  int n;                /* even number of grid points */
  double z[MAXGRD];     /* grid points */
  double w[MAXGRD];     /* width, w[j]=z[j]-z[j-1] */
  double p[MAXGRD];     /* lower normal prob at z[j] */
  double d[MAXGRD];     /* normal density at z[j] */
  double w2[MAXGRD];    /* w squared */
  double w3[MAXGRD];    /* w cubed */
  double q[MAXGRD][4];  /* integral (x - z[j-1])^i * phi(x) */
};

